@@ -2,7 +2,7 @@ import datetime
 
 from playhouse.shortcuts import model_to_dict
 
-from data_base_model import PatientProblems
+from qa_data_manager.data_base_model import PatientProblems
 
 
 class GeneratePatientProblem:
